@@ -120,24 +120,12 @@ class PhotovoltaicPowerPlant(Generator):
         # calculate heat balance, irradiance induced heat flow
         # (Watt/m2, pos. sign indicates heat uptake of plant)
         if not self.config.is_static_t_module:
-            q_dot_irradiance = irradiance_w_per_m2 * (
-                1
-                - self.config.eta_percent / 100
-                - self.config.reflex_percent / 100
-            )
-            # heat flow induced by temperature gradient between module and air
-            q_dot_temp_grad = self.config.alpha_w_per_m2_kelvin * (
-                self.inputs.t_air_deg_celsius - self.state.t_module_deg_celsius
-            )
-            # heat transfer in current time step [J/m2]
-            e_j_per_m2 = (
-                q_dot_irradiance + q_dot_temp_grad
-            ) * self.inputs.step_size
-            # calculate new temperature of module
-            self.state.t_module_deg_celsius += e_j_per_m2 / (
-                self.config.rho_kg_per_m2 * self.config.c_j_per_kg_kelvin
+            t_module_change = self._calculate_module_temperature(
+                irradiance_w_per_m2
             )
 
+            self.state.t_module_deg_celsius += t_module_change
+
         # temperature for which eta_percent was measured
         t_ref_deg_celsius = 25  # °C
 
@@ -182,3 +170,34 @@ class PhotovoltaicPowerPlant(Generator):
 
         if error:
             raise KeyError("At least one input is not set")
+
+    def _calculate_module_temperature(self, irradiance_w_per_m2):
+        if self.inputs.step_size > self.config.max_step_size:
+            steps = self.inputs.step_size // self.config.max_step_size
+            step_sizes = [self.config.max_step_size] * steps
+            remainder = self.inputs.step_size % self.config.max_step_size
+            if remainder > 0:
+                step_sizes.append(remainder)
+
+        else:
+            step_sizes = [self.inputs.step_size]
+
+        t_module = self.state.t_module_deg_celsius
+
+        for step_size in step_sizes:
+            q_dot_irradiance = irradiance_w_per_m2 * (
+                1
+                - self.config.eta_percent / 100
+                - self.config.reflex_percent / 100
+            )
+            # heat flow induced by temperature gradient between module and air
+            q_dot_temp_grad = self.config.alpha_w_per_m2_kelvin * (
+                self.inputs.t_air_deg_celsius - t_module
+            )
+            # heat transfer in current time step [J/m2]
+            e_j_per_m2 = (q_dot_irradiance + q_dot_temp_grad) * step_size
+            # calculate new temperature of module
+            t_module += e_j_per_m2 / (
+                self.config.rho_kg_per_m2 * self.config.c_j_per_kg_kelvin
+            )
+        return t_module - self.state.t_module_deg_celsius
