@@ -19,6 +19,7 @@ META = {
                 "p_mw",
                 "q_mvar",
                 "soc_percent",
+                "local_time",
             ],
         },
         "Photovoltaic": {
@@ -33,6 +34,8 @@ META = {
                 "bh_w_per_m2",
                 "dh_w_per_m2",
                 "s_module_w_per_m2",
+                "local_time",
+                "inverter_inductive",
             ],
         },
         "CHP": {
@@ -44,6 +47,7 @@ META = {
                 "q_mvar",
                 "day_avg_t_air_deg_celsius",
                 "p_th_mw",
+                "local_time",
             ],
         },
         "HVAC": {
@@ -54,17 +58,24 @@ META = {
                 "p_mw",
                 "q_mvar",
                 "t_air_deg_celsius",
+                "local_time",
             ],
         },
         "Biogas": {
             "public": True,
             "params": ["params", "inits"],
-            "attrs": ["set_percent", "p_mw", "q_mvar", "p_th_mw"],
+            "attrs": [
+                "set_percent",
+                "p_mw",
+                "q_mvar",
+                "p_th_mw",
+                "local_time",
+            ],
         },
         "DieselGenerator": {
             "public": True,
             "params": ["params", "inits"],
-            "attrs": ["set_percent", "p_mw", "q_mvar"],
+            "attrs": ["set_percent", "p_mw", "q_mvar", "local_time"],
         },
     },
 }
