@@ -4,9 +4,12 @@ of the pysimmods package.
 """
 import pprint
 from datetime import datetime, timedelta, timezone
-import distutils
+from multiprocessing.sharedctypes import Value
+
 import mosaik_api
 import numpy as np
+from midas.util.dict_util import strtobool
+from midas.util.logging import set_and_init_logger
 from pysimmods.mosaik import LOG
 from pysimmods.util.date_util import GER
 
@@ -58,10 +61,8 @@ class PysimmodsSimulator(mosaik_api.Simulator):
         use_decimal_percent = sim_params.get("use_decimal_percent", False)
         if not isinstance(use_decimal_percent, bool):
             try:
-                use_decimal_percent = bool(
-                    distutils.util.strtobool(use_decimal_percent)
-                )
-            except AttributeError:
+                use_decimal_percent = strtobool(use_decimal_percent)
+            except ValueError:
                 use_decimal_percent = False
 
         if use_decimal_percent:
@@ -170,6 +171,7 @@ class PysimmodsSimulator(mosaik_api.Simulator):
         # Step the models
         for model in self.models.values():
             model.step()
+            p = model.state.p_kw
 
         # Update time for the next step
         self.now_dt += timedelta(seconds=self.step_size)
@@ -217,4 +219,8 @@ class PysimmodsSimulator(mosaik_api.Simulator):
 
 
 if __name__ == "__main__":
+    set_and_init_logger(
+        0, "pysimmods-logfile", "pysimmods-mosaik.log", replace=True
+    )
+    LOG.info("Starting mosaik simulation...")
     mosaik_api.start_simulation(PysimmodsSimulator())
